==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkAnnotationLayers.java <==
// java wrapper for vtkAnnotationLayers object
//

package vtk;
import vtk.*;

public class vtkAnnotationLayers extends vtkDataObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetCurrentAnnotation_2(vtkAnnotation id0);
  public void SetCurrentAnnotation(vtkAnnotation id0)
    { SetCurrentAnnotation_2(id0); }

  private native long GetCurrentAnnotation_3();
  public vtkAnnotation GetCurrentAnnotation() {
    long temp = GetCurrentAnnotation_3();

    if (temp == 0) return null;
    return (vtkAnnotation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetCurrentSelection_4(vtkSelection id0);
  public void SetCurrentSelection(vtkSelection id0)
    { SetCurrentSelection_4(id0); }

  private native long GetCurrentSelection_5();
  public vtkSelection GetCurrentSelection() {
    long temp = GetCurrentSelection_5();

    if (temp == 0) return null;
    return (vtkSelection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int GetNumberOfAnnotations_6();
  public int GetNumberOfAnnotations()
    { return GetNumberOfAnnotations_6(); }

  private native long GetAnnotation_7(int id0);
  public vtkAnnotation GetAnnotation(int id0) {
    long temp = GetAnnotation_7(id0);

    if (temp == 0) return null;
    return (vtkAnnotation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void AddAnnotation_8(vtkAnnotation id0);
  public void AddAnnotation(vtkAnnotation id0)
    { AddAnnotation_8(id0); }

  private native void RemoveAnnotation_9(vtkAnnotation id0);
  public void RemoveAnnotation(vtkAnnotation id0)
    { RemoveAnnotation_9(id0); }

  private native void Initialize_10();
  public void Initialize()
    { Initialize_10(); }

  private native void ShallowCopy_11(vtkDataObject id0);
  public void ShallowCopy(vtkDataObject id0)
    { ShallowCopy_11(id0); }

  private native void DeepCopy_12(vtkDataObject id0);
  public void DeepCopy(vtkDataObject id0)
    { DeepCopy_12(id0); }

  private native long GetData_13(vtkInformation id0);
  public vtkAnnotationLayers GetData(vtkInformation id0) {
    long temp = GetData_13(id0);

    if (temp == 0) return null;
    return (vtkAnnotationLayers)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetData_14(vtkInformationVector id0,int id1);
  public vtkAnnotationLayers GetData(vtkInformationVector id0,int id1) {
    long temp = GetData_14(id0,id1);

    if (temp == 0) return null;
    return (vtkAnnotationLayers)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int GetMTime_15();
  public int GetMTime()
    { return GetMTime_15(); }

  public vtkAnnotationLayers() { super(); }

  public vtkAnnotationLayers(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-19-aarch64.pkg.tar.xz: vtk/vtkAnnotationLayers.java <==
// java wrapper for vtkAnnotationLayers object
//

package vtk;
import vtk.*;

public class vtkAnnotationLayers extends vtkDataObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetCurrentAnnotation_2(vtkAnnotation id0);
  public void SetCurrentAnnotation(vtkAnnotation id0)
    { SetCurrentAnnotation_2(id0); }

  private native long GetCurrentAnnotation_3();
  public vtkAnnotation GetCurrentAnnotation() {
    long temp = GetCurrentAnnotation_3();

    if (temp == 0) return null;
    return (vtkAnnotation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetCurrentSelection_4(vtkSelection id0);
  public void SetCurrentSelection(vtkSelection id0)
    { SetCurrentSelection_4(id0); }

  private native long GetCurrentSelection_5();
  public vtkSelection GetCurrentSelection() {
    long temp = GetCurrentSelection_5();

    if (temp == 0) return null;
    return (vtkSelection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfAnnotations_6();
  public int GetNumberOfAnnotations()
    { return GetNumberOfAnnotations_6(); }

  private native long GetAnnotation_7(int id0);
  public vtkAnnotation GetAnnotation(int id0) {
    long temp = GetAnnotation_7(id0);

    if (temp == 0) return null;
    return (vtkAnnotation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void AddAnnotation_8(vtkAnnotation id0);
  public void AddAnnotation(vtkAnnotation id0)
    { AddAnnotation_8(id0); }

  private native void RemoveAnnotation_9(vtkAnnotation id0);
  public void RemoveAnnotation(vtkAnnotation id0)
    { RemoveAnnotation_9(id0); }

  private native void Initialize_10();
  public void Initialize()
    { Initialize_10(); }

  private native void ShallowCopy_11(vtkDataObject id0);
  public void ShallowCopy(vtkDataObject id0)
    { ShallowCopy_11(id0); }

  private native void DeepCopy_12(vtkDataObject id0);
  public void DeepCopy(vtkDataObject id0)
    { DeepCopy_12(id0); }

  private native long GetData_13(vtkInformation id0);
  public vtkAnnotationLayers GetData(vtkInformation id0) {
    long temp = GetData_13(id0);

    if (temp == 0) return null;
    return (vtkAnnotationLayers)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetData_14(vtkInformationVector id0,int id1);
  public vtkAnnotationLayers GetData(vtkInformationVector id0,int id1) {
    long temp = GetData_14(id0,id1);

    if (temp == 0) return null;
    return (vtkAnnotationLayers)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetMTime_15();
  public int GetMTime()
    { return GetMTime_15(); }

  public vtkAnnotationLayers() { super(); }

  public vtkAnnotationLayers(long id) { super(id); }
  public native long   VTKInit();

}
